import config from './config';

/**
 * 拼接对象为请求字符串
 * @param {Object} obj - 待拼接的对象
 * @returns {string} - 拼接成的请求字符串
 */
function encodeSearchParams(obj) {
  let params = [];

  Object.keys(obj).forEach(key => {
    let value = obj[key];
    // 如果值为undefined我们将其置空
    if (typeof value === 'undefined') {
      value = '';
    }
    // 对于需要编码的文本（比如说中文）我们要进行编码
    params.push([key, encodeURIComponent(value)].join('='));
  });

  return params.join('&');
}

/**
 * 记录网站来源
 * @param {string} siteID 网站 id
 *
 */
function track(siteID) {
  const referrer = document.referrer;
  const currentUrl = window.location.href;
  const requestUrl = config.requestUrl;

  if (referrer && referrer !== currentUrl) {
    const params = {
      sourceUrl: referrer,
      currentUrl,
      trackingCode: siteID
    };

    const finalUrl = `${requestUrl}?${encodeSearchParams(params)}`;

    const xhr = new XMLHttpRequest();
    xhr.open('get', finalUrl, true);
    xhr.send();
  }
}

const sourceTrack = {
  config(params = {}) {
    const { siteId } = params;

    if (!siteId) {
      console.error('请配置 siteID');
      return;
    }

    this.siteID = siteId;

    this.init();
  },

  init() {
    const { siteID } = this;
    track(siteID);
  }
};

export default sourceTrack;
